//***************** (c) 2009 BTC Korporacja ***********************************
//                     http://www.kamami.com
// PROJECT  : KAmodBAR-SPI Example
// BOARD    : ZL29ARM
//
//******************************************************************************
//
//    THE SOFTWARE INCLUDED IN THIS FILE IS FOR GUIDANCE ONLY.
//    BTC KORPORACJA SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
//    OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
//    FROM USE OF THIS SOFTWARE.
//
//******************************************************************************
//
// DESCRIPTION :
//    Simple example for KAmodBAR-SPI and ZL29ARM board.
//	  ZL29ARM displays pressure read from KAmodBAR-SPI on 2x16 char display.
//
//    Settings and connections on ZL29ARM:
//		
//
//        JP3 (DISPLAY) - 2-3 (CHAR)
//		  JP7 (BOOT0)	- 1-2 (0)
//		  JP8 (BOOT1)	- 1-2 (0)
//
//   Connections between ZL29ARM and KAmodBAR-SPI:
//		  Con7 (ZL29ARM) - Con2 (KAmodBAR-SPI) EXCEPT FOR pin 1 on ZL29ARM side, 
//		  which has to be connected	to +3.3V (for example pin 9 of Con4 or Con5).
//		
// 
//
//******************************************************************************
// 


#include "stm32f10x.h"
#include "hd44780.h"


void System_Config(void)
{
	// Enable Prefetch Buffer
	FLASH->ACR |= FLASH_ACR_PRFTBE;
    // Flash 2 wait state 
    FLASH->ACR = (FLASH->ACR & ~FLASH_ACR_LATENCY) | FLASH_ACR_LATENCY_2; 
						
	// Enable HSE 
	RCC->CR |= RCC_CR_HSEON;
	while (RCC->CR & RCC_CR_HSERDY == 0);
							
  	// PREDIV1 source = HSE
	RCC->CFGR &= ~RCC_CFGR_PPRE1;

	// PLLSRC = PREDIV1
	RCC->CFGR |= RCC_CFGR_PLLSRC;
							  
	// PLL = PREDIV1 * 4 => SYSCLK = 40 MHz
	RCC->CFGR = (RCC->CFGR & ~RCC_CFGR_PLLMULL) | RCC_CFGR_PLLMULL_1;
							  
	// PLL enable
	RCC->CR |= RCC_CR_PLLON;
	while ((RCC->CR & RCC_CR_PLLRDY) == 0);

    RCC->CFGR = (RCC->CFGR & ~RCC_CFGR_SW) | RCC_CFGR_SW_PLL;
	while((RCC->CFGR & RCC_CFGR_SWS) != RCC_CFGR_SWS_PLL);					 

	RCC->APB2ENR |= RCC_APB2ENR_IOPEEN;
}


void SysTick_Handler()
{
	char buf[128];
	double Pressure;
  	MPL115AReadPressureAndTempADC();
	MPL115ACalculatePressure(&Pressure);
	LCD_GoTo(0,1);
	sprintf(buf, "Press. %.1f kPa ", Pressure);
	LCD_WriteText(buf);
}


int main()
{
	System_Config();
	LCD_Initialize();
	LCD_GoTo(0, 0);
	LCD_WriteText("KAmodBAR+ZL29ARM");
	MPL115AIntitalize();
	MPL115AReadCoeffs();

	// Enable Systick interrupt with 500ms interval
	SysTick->LOAD = 2000000000;
	SysTick->CTRL |= SysTick_CTRL_ENABLE | SysTick_CTRL_TICKINT;

	while(1)
	{	  
	}
}